Package: binutils
Version: 2.20.1-15
Severity: wishlist
Tags: upstream patch


Hi,

Lintian complains about various spelling errors in the generated
binaries after building binutils. The attached patch fixes those which
are actual spelling errors (Lintian complains about "mmnemonic" which
isn't a mistake since it refers to the "-mmnemonic" switch).

The patch was generated using

export mistake=endianess; export correction=endianness; \
quilt add $(grep -Rl $mistake *); \
for file in $(grep -Rl $mistake *); \
do sed -i "s/$mistake/$correction/g" $file; \
done; \
quilt refresh; \
unset correction; unset mistake

(rinse and repeat for all the errors found by Lintian) and checked
manually. It probably fuzzies the translations, I haven't unfuzzied
them.

The patch applies against binutils 2.20.90.20101121.

Regards,

Stephen

-- System Information:
Debian Release: squeeze/sid
  APT prefers testing
  APT policy: (500, 'testing'), (500, 'stable'), (200, 'unstable'), (1, 
'experimental')
Architecture: i386 (i686)

Kernel: Linux 2.6.35-trunk-686-bigmem (SMP w/2 CPU cores)
Locale: LANG=en_GB.UTF-8, LC_CTYPE=en_GB.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash

Versions of packages binutils depends on:
ii  libc6                   2.11.2-7         Embedded GNU C Library: Shared lib
ii  libgcc1                 1:4.5.1-11       GCC support library
ii  libstdc++6              4.5.1-11         The GNU Standard C++ Library v3
ii  zlib1g                  1:1.2.3.4.dfsg-3 compression library - runtime

binutils recommends no packages.

Versions of packages binutils suggests:
ii  binutils-doc                  2.20.1-15  Documentation for the GNU assemble

-- debconf information:
  binutils/oformat_warning:
* binutils/kernel_link_warning:
--- binutils-2.20.90.20101121.orig/bfd/ChangeLog-0001
+++ binutils-2.20.90.20101121/bfd/ChangeLog-0001
@@ -8159,21 +8159,21 @@
 
 2000-05-22  Momchil Velikov  <[email protected]>
 
-       * libbfd.c (_bfd_generic_verify_endian_match): Compare endianess
+       * libbfd.c (_bfd_generic_verify_endian_match): Compare endianness
        only if it is known for both input and output bfds. Separate
        error message strings as in some languages, it may be necessary
        to change more than one place in the string to change between
        'big' and 'little'.
 
        * elf32-ppc.c (ppc_elf_merge_private_bfd_data): Remove inline
-       endianess checks, call _bfd_generic_verify_endian_match() instead.
+       endianness checks, call _bfd_generic_verify_endian_match() instead.
 
        * elf32-mips.c (_bfd_mips_elf_merge_private_bfd_data): Likewise.
 
        * elf32-mcore.c (mcore_elf_merge_private_bfd_data): Likewise.
 
        * elf32-arm.h (elf32_arm_merge_private_bfd_data): Likewise. Verify
-       endianess before checking bfd flavours.
+       endianness before checking bfd flavours.
 
 2000-05-22  H.J. Lu  <[email protected]>
 
--- binutils-2.20.90.20101121.orig/bfd/ChangeLog-9193
+++ binutils-2.20.90.20101121/bfd/ChangeLog-9193
@@ -1563,7 +1563,7 @@
        * coff-alpha.c (alpha_ecoff_backend_data): Removed initialization
        of big_magic and little_magic.
        * coff-mips.c (mips_ecoff_bad_format_hook): Make sure magic number
-       matches endianess of bfd.
+       matches endianness of bfd.
        (mips_ecoff_backend_data): Removed initialization of big_magic and
        little_magic.
        * ecoff.c (ecoff_set_arch_mach_hook): Set MIPS machine number
@@ -6085,7 +6085,7 @@
        * configure.in:  fix vax ultrix configuration.
 
        * elf.c (bfd_section_from_shdr):  Deal with null return from
-       bfd_make_section().  (elf_object_p):  Select endianess properly.
+       bfd_make_section().  (elf_object_p):  Select endianness properly.
 
 Fri Jan 31 01:19:55 1992  John Gilmore  (gnu at cygnus.com)
 
@@ -6994,7 +6994,7 @@
        setup the environment.
 
        * archive.c: (bfd_slurp_coff_armap) coff archives always have the
-       headers in big endian format, regardless of the endianess of the
+       headers in big endian format, regardless of the endianness of the
        host or target.
 
        * archures.c: totally changed. Now an architecture is represented
--- binutils-2.20.90.20101121.orig/bfd/coff-mcore.c
+++ binutils-2.20.90.20101121/bfd/coff-mcore.c
@@ -377,7 +377,7 @@
   if (info->relocatable)
     return TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (   input_bfd->xvec->byteorder != output_bfd->xvec->byteorder
       && output_bfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
     {
--- binutils-2.20.90.20101121.orig/bfd/coff-stgo32.c
+++ binutils-2.20.90.20101121/bfd/coff-stgo32.c
@@ -102,7 +102,7 @@
 
 #include "coff-i386.c"
 
-/* This macro is used, because I cannot assume the endianess of the
+/* This macro is used, because I cannot assume the endianness of the
    host system.  */
 #define _H(index) (H_GET_16 (abfd, (header+index*2)))
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-arm.c
+++ binutils-2.20.90.20101121/bfd/elf32-arm.c
@@ -8987,7 +8987,7 @@
                    - relocation;
                  addend += msec->output_section->vma + msec->output_offset;
 
-                 /* Cases here must match those in the preceeding
+                 /* Cases here must match those in the preceding
                     switch statement.  */
                  switch (r_type)
                    {
@@ -13966,7 +13966,7 @@
   bfd_boolean flags_compatible = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-m68hc1x.c
+++ binutils-2.20.90.20101121/bfd/elf32-m68hc1x.c
@@ -1188,7 +1188,7 @@
   flagword new_flags;
   bfd_boolean ok = TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-mcore.c
+++ binutils-2.20.90.20101121/bfd/elf32-mcore.c
@@ -55,7 +55,7 @@
   flagword old_flags;
   flagword new_flags;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-mep.c
+++ binutils-2.20.90.20101121/bfd/elf32-mep.c
@@ -605,7 +605,7 @@
   flagword old_flags, new_flags;
   flagword old_partial, new_partial;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-mt.c
+++ binutils-2.20.90.20101121/bfd/elf32-mt.c
@@ -521,7 +521,7 @@
   flagword     old_flags, new_flags;
   bfd_boolean  ok = TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-ppc.c
+++ binutils-2.20.90.20101121/bfd/elf32-ppc.c
@@ -4163,7 +4163,7 @@
   if (!is_ppc_elf (ibfd) || !is_ppc_elf (obfd))
     return TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf32-xtensa.c
+++ binutils-2.20.90.20101121/bfd/elf32-xtensa.c
@@ -3466,7 +3466,7 @@
   unsigned out_mach, in_mach;
   flagword out_flag, in_flag;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
--- binutils-2.20.90.20101121.orig/bfd/elf64-ppc.c
+++ binutils-2.20.90.20101121/bfd/elf64-ppc.c
@@ -2730,7 +2730,7 @@
 static bfd_boolean
 ppc64_elf_merge_private_bfd_data (bfd *ibfd, bfd *obfd)
 {
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (ibfd->xvec->byteorder != obfd->xvec->byteorder
       && ibfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN
       && obfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
--- binutils-2.20.90.20101121.orig/bfd/elfxx-mips.c
+++ binutils-2.20.90.20101121/bfd/elfxx-mips.c
@@ -12514,7 +12514,7 @@
   bfd_boolean null_input_bfd = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     {
       (*_bfd_error_handler)
--- binutils-2.20.90.20101121.orig/bfd/netbsd.h
+++ binutils-2.20.90.20101121/bfd/netbsd.h
@@ -108,7 +108,7 @@
   /* The NetBSD magic number is always big-endian */
 #ifndef TARGET_IS_BIG_ENDIAN_P
   /* XXX aren't there any macro to change byteorder of a word independent of
-     the host's or target's endianesses?  */
+     the host's or target's endiannesses?  */
   execp->a_info
     = (execp->a_info & 0xff) << 24 | (execp->a_info & 0xff00) << 8
       | (execp->a_info & 0xff0000) >> 8 | (execp->a_info & 0xff000000) >> 24;
--- binutils-2.20.90.20101121.orig/bfd/nlmcode.h
+++ binutils-2.20.90.20101121/bfd/nlmcode.h
@@ -491,7 +491,7 @@
                  NLM_SIGNATURE_SIZE) != 0)
     goto got_wrong_format_error;
 
-  /* There's no supported way to discover the endianess of an NLM, so test for
+  /* There's no supported way to discover the endianness of an NLM, so test for
      a sane version number after doing byte swapping appropriate for this
      XVEC.  (Hack alert!)  */
   if (i_fxdhdrp->version > 0xFFFF)
--- binutils-2.20.90.20101121.orig/binutils/ChangeLog-2007
+++ binutils-2.20.90.20101121/binutils/ChangeLog-2007
@@ -687,7 +687,7 @@
        * resres.c: Likewise.
        * resrc.c: Likewise. Dumps as RC are now recompilable.
        * windres.c: As above. Using bfd for res and provide target
-       specific endianess support.
+       specific endianness support.
        * windres.h: Use windint.h as include. Additionally removed K&R
        syntax.
        * winduni.c: New printing and unichar support routines.
--- binutils-2.20.90.20101121.orig/binutils/ChangeLog-2008
+++ binutils-2.20.90.20101121/binutils/ChangeLog-2008
@@ -840,8 +840,8 @@
        PR binutils/55326
        * bucomm.c (list_supported_architectures): Free architecture list
        after use.
-       * windres.c (set_endianess): Likewise.
-       * windmc.c (set_endianess): Likewise.
+       * windres.c (set_endianness): Likewise.
+       * windmc.c (set_endianness): Likewise.
 
 2008-01-08  Kai Tietz  <[email protected]>
 
--- binutils-2.20.90.20101121.orig/binutils/ChangeLog-2009
+++ binutils-2.20.90.20101121/binutils/ChangeLog-2009
@@ -128,8 +128,8 @@
 
 2009-11-16  Kai Tietz  <[email protected]>
 
-       * windmc.c (set_endianess): Use bfd_get_target_info.
-       * windres.c (set_endianess): Likewise.
+       * windmc.c (set_endianness): Use bfd_get_target_info.
+       * windres.c (set_endianness): Likewise.
        (find_arch_match): Removed.
 
 2009-11-11  Nick Clifton  <[email protected]>
@@ -1122,7 +1122,7 @@
 
 2009-02-09  Kai Tietz  <[email protected]>
 
-       * windres.c (set_endianess): Copy name without leading '-'.
+       * windres.c (set_endianness): Copy name without leading '-'.
 
 2009-02-09  Tristan Gingold  <[email protected]>
 
@@ -1339,7 +1339,7 @@
 
 2009-01-06  Kai Tietz  <[email protected]>
 
-       * windres.c (set_endianess): Get architecture name
+       * windres.c (set_endianness): Get architecture name
        for internal target names like "pe-arm-wince-little".
        (find_arch_match): New helper.
        * ChangeLog: Reset it.
--- binutils-2.20.90.20101121.orig/binutils/NEWS
+++ binutils-2.20.90.20101121/binutils/NEWS
@@ -111,7 +111,7 @@
 
 * Add codepage support to the windres tool.  It now supports many new
   resource types (e.g. MANIFEST, TOOLBAR, etc).  The output generation
-  for binary files is done now via bfd itself.  The endianess problems
+  for binary files is done now via bfd itself.  The endianness problems
   for different hosts are solved.  Dumps of .res files can now be
   re-compiled by windres without lossing resources or compilation errors.
   Some problems on dialog resource translations are corrected.
--- binutils-2.20.90.20101121.orig/binutils/po/bg.po
+++ binutils-2.20.90.20101121/binutils/po/bg.po
@@ -5825,7 +5825,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/binutils.pot
+++ binutils-2.20.90.20101121/binutils/po/binutils.pot
@@ -6791,7 +6791,7 @@
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header "
 "file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/da.po
+++ binutils-2.20.90.20101121/binutils/po/da.po
@@ -5920,7 +5920,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/es.po
+++ binutils-2.20.90.20101121/binutils/po/es.po
@@ -6358,7 +6358,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/fi.po
+++ binutils-2.20.90.20101121/binutils/po/fi.po
@@ -6484,7 +6484,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/fr.po
+++ binutils-2.20.90.20101121/binutils/po/fr.po
@@ -7145,7 +7145,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -7165,7 +7165,7 @@
 "  -C --codepage_in=<val>       Choisi le codepage lors de la lecture du 
fichier texte mc\n"
 "  -d --decimal_values          Affiche les valeurs du fichier texte en 
d??cimal\n"
 "  -e --extension=<extension>   Choisi l'extension de l'en-t??te utilis??e 
pour exporter l'en-t??te du fichier\n"
-"  -F --target <cible>          Sp??cifie l'ordre des octets (endianess) de la 
sortie.\n"
+"  -F --target <cible>          Sp??cifie l'ordre des octets (endianness) de 
la sortie.\n"
 "  -h --headerdir=<r??pertoire>  Choisi le r??pertoire pour exporter les 
en-t??tes\n"
 "  -u --unicode_in              Lit le fichier d'entr??e en UTF16\n"
 "  -U --unicode_out             ??crit les messages binaires en UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/id.po
+++ binutils-2.20.90.20101121/binutils/po/id.po
@@ -6244,7 +6244,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/ja.po
+++ binutils-2.20.90.20101121/binutils/po/ja.po
@@ -7097,7 +7097,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/ru.po
+++ binutils-2.20.90.20101121/binutils/po/ru.po
@@ -6340,7 +6340,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -6360,7 +6360,7 @@
 "  -C --codepage_in=<????????>      ???????????????????? ?????????????????? 
?????? ???????????? ???????????????????? mc-??????????\n"
 "  -d --decimal_values          ?????????????? ???????????????? ?? 
?????????????????? ???????? ?? ???????????????????? ????????\n"
 "  -e --extension=<????????????????????>  ???????????????????? 
???????????????????? ?????? ??????????????????, ???????????????????????? ?? 
?????????? ???????????????? ??????????????????\n"
-"  -F --target <????????>           ?????????????? ???????????????? ???????? 
?????? endianess.\n"
+"  -F --target <????????>           ?????????????? ???????????????? ???????? 
?????? endianness.\n"
 "  -h --headerdir=<??????????????>     ???????????????????? ?????????????? 
?????? ???????????????? ????????????????????\n"
 "  -u --unicode_in              ???????????? ?????????????? ???????? ?????? 
???????? UTF16\n"
 "  -U --unicode_out             ???????????????????? ???????????????? 
?????????????????? ?? ?????????????? UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/sk.po
+++ binutils-2.20.90.20101121/binutils/po/sk.po
@@ -6037,7 +6037,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/uk.po
+++ binutils-2.20.90.20101121/binutils/po/uk.po
@@ -5617,7 +5617,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
@@ -5637,7 +5637,7 @@
 "  -C --codepage_in=<????????????????>  ???????????????????? ???????????? 
???????????????? ?????? ?????????????? ???????????????????? ?????????? mc\n"
 "  -d --decimal_values          ???????????????? ???????????????? ?? 
?????????????????? ???????? ?? ?????????????????????? ??????????????\n"
 "  -e --extension=<????????????????????>  ???????????????????? 
???????????????????? ??????????????????, ???? 
?????????????????????????????????? ?????? ???????????????? ?????????? 
??????????????????\n"
-"  -F --target <target>         ???????????? ???????? ???????????? ?????? 
endianess.\n"
+"  -F --target <target>         ???????????? ???????? ???????????? ?????? 
endianness.\n"
 "  -h --headerdir=<??????????????>     ???????????????????? ?????????????? 
???????????????? ?????? ????????????????????\n"
 "  -u --unicode_in              ?????????????????? ???????????????? ?????????? 
UTF16\n"
 "  -U --unicode_out             ?????????????????? ?????????? ???????????? 
UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/po/vi.po
+++ binutils-2.20.90.20101121/binutils/po/vi.po
@@ -6410,7 +6410,7 @@
 "  -C --codepage_in=<val>       Set codepage when reading mc text file\n"
 "  -d --decimal_values          Print values to text files decimal\n"
 "  -e --extension=<extension>   Set header extension used on export header 
file\n"
-"  -F --target <target>         Specify output target for endianess.\n"
+"  -F --target <target>         Specify output target for endianness.\n"
 "  -h --headerdir=<directory>   Set the export directory for headers\n"
 "  -u --unicode_in              Read input file as UTF16 file\n"
 "  -U --unicode_out             Write binary messages as UFT16\n"
--- binutils-2.20.90.20101121.orig/binutils/resres.c
+++ binutils-2.20.90.20101121/binutils/resres.c
@@ -98,7 +98,7 @@
   off = 0;
 
   if (! probe_binary (&wrbfd, flen))
-    set_windres_bfd_endianess (&wrbfd, ! target_is_bigendian);
+    set_windres_bfd_endianness (&wrbfd, ! target_is_bigendian);
 
   skip_null_resource (&wrbfd, &off, flen);
 
--- binutils-2.20.90.20101121.orig/binutils/windint.h
+++ binutils-2.20.90.20101121/binutils/windint.h
@@ -1083,6 +1083,6 @@
 extern rc_uint_type windres_get_32 (windres_bfd *, const void *, rc_uint_type);
 
 extern void set_windres_bfd (windres_bfd *, bfd *, asection *, rc_uint_type);
-extern void set_windres_bfd_endianess (windres_bfd *, int);
+extern void set_windres_bfd_endianness (windres_bfd *, int);
 
 #endif
--- binutils-2.20.90.20101121.orig/binutils/windmc.c
+++ binutils-2.20.90.20101121/binutils/windmc.c
@@ -205,7 +205,7 @@
   -C --codepage_in=<val>       Set codepage when reading mc text file\n\
   -d --decimal_values          Print values to text files decimal\n\
   -e --extension=<extension>   Set header extension used on export header 
file\n\
-  -F --target <target>         Specify output target for endianess.\n\
+  -F --target <target>         Specify output target for endianness.\n\
   -h --headerdir=<directory>   Set the export directory for headers\n\
   -u --unicode_in              Read input file as UTF16 file\n\
   -U --unicode_out             Write binary messages as UFT16\n\
@@ -231,7 +231,7 @@
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -239,7 +239,7 @@
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
                                   &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1054,7 +1054,7 @@
       ++optind;
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   if (input_filename == NULL)
     {
--- binutils-2.20.90.20101121.orig/binutils/windres.c
+++ binutils-2.20.90.20101121/binutils/windres.c
@@ -54,7 +54,7 @@
 int target_is_bigendian = 0;
 const char *def_target_arch;
 
-static void set_endianess (bfd *, const char *);
+static void set_endianness (bfd *, const char *);
 
 /* An enumeration of format types.  */
 
@@ -1028,7 +1028,7 @@
        output_format = format_from_filename (output_filename, 0);
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   /* Read the input file.  */
   switch (input_format)
@@ -1077,7 +1077,7 @@
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -1085,7 +1085,7 @@
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
                                    &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1106,7 +1106,7 @@
 }
 
 void
-set_windres_bfd_endianess (windres_bfd *wrbfd, int is_bigendian)
+set_windres_bfd_endianness (windres_bfd *wrbfd, int is_bigendian)
 {
   assert (!! wrbfd);
   switch (WR_KIND(wrbfd))
--- binutils-2.20.90.20101121.orig/gas/config/tc-ppc.c
+++ binutils-2.20.90.20101121/gas/config/tc-ppc.c
@@ -1124,7 +1124,7 @@
       else if (strcmp (arg, "emb") == 0)
        ppc_flags |= EF_PPC_EMB;
 
-      /* -mlittle/-mbig set the endianess.  */
+      /* -mlittle/-mbig set the endianness.  */
       else if (strcmp (arg, "little") == 0
               || strcmp (arg, "little-endian") == 0)
        {
--- binutils-2.20.90.20101121.orig/gold/output.cc
+++ binutils-2.20.90.20101121/gold/output.cc
@@ -411,7 +411,7 @@
     }
 }
 
-// Write out the file header with appropriate size and endianess.
+// Write out the file header with appropriate size and endianness.
 
 template<int size, bool big_endian>
 void
--- binutils-2.20.90.20101121.orig/ld/po/da.po
+++ binutils-2.20.90.20101121/ld/po/da.po
@@ -575,7 +575,7 @@
 
 #: ldlang.c:1853
 msgid "%P: warning: could not find any targets that match endianness 
requirement\n"
-msgstr "%P: advarsel: kunne ikke finde nogen m?l som matcher kravet p? 
endianess\n"
+msgstr "%P: advarsel: kunne ikke finde nogen m?l som matcher kravet p? 
endianness\n"
 
 #: ldlang.c:1866
 msgid "%P%F: target %s not found\n"
--- binutils-2.20.90.20101121.orig/ld/po/sv.po
+++ binutils-2.20.90.20101121/ld/po/sv.po
@@ -607,7 +607,7 @@
 
 #: ldlang.c:1698
 msgid "%P: warning: could not find any targets that match endianness 
requirement\n"
-msgstr "%P: varning: kunde inte hitta n?gra m?l som matchar kravet p? 
endianess\n"
+msgstr "%P: varning: kunde inte hitta n?gra m?l som matchar kravet p? 
endianness\n"
 
 #: ldlang.c:1711
 msgid "%P%F: target %s not found\n"
--- binutils-2.20.90.20101121.orig/bfd/elf32-avr.c
+++ binutils-2.20.90.20101121/bfd/elf32-avr.c
@@ -1994,10 +1994,10 @@
                 if ((0x95 == next_insn_msb) && (0x08 == next_insn_lsb))
                   {
                     /* The next insn is a ret. We possibly could delete
-                       this ret. First we need to check for preceeding
+                       this ret. First we need to check for preceding
                        sbis/sbic/sbrs or cpse "skip" instructions.  */
 
-                    int there_is_preceeding_non_skip_insn = 1;
+                    int there_is_preceding_non_skip_insn = 1;
                     bfd_vma address_of_ret;
 
                     address_of_ret = dot + insn_size;
@@ -2009,51 +2009,51 @@
                       printf ("found jmp / ret sequence at address 0x%x\n",
                               (int) dot);
 
-                    /* We have to make sure that there is a preceeding insn.  
*/
+                    /* We have to make sure that there is a preceding insn.  */
                     if (irel->r_offset >= 2)
                       {
-                        unsigned char preceeding_msb;
-                        unsigned char preceeding_lsb;
-                        preceeding_msb =
+                        unsigned char preceding_msb;
+                        unsigned char preceding_lsb;
+                        preceding_msb =
                          bfd_get_8 (abfd, contents + irel->r_offset - 1);
-                        preceeding_lsb =
+                        preceding_lsb =
                          bfd_get_8 (abfd, contents + irel->r_offset - 2);
 
                         /* sbic.  */
-                        if (0x99 == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x99 == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbis.  */
-                        if (0x9b == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x9b == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrc */
-                        if ((0xfc == (preceeding_msb & 0xfe)
-                            && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfc == (preceding_msb & 0xfe)
+                            && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrs */
-                        if ((0xfe == (preceeding_msb & 0xfe)
-                            && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfe == (preceding_msb & 0xfe)
+                            && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* cpse */
-                        if (0x10 == (preceeding_msb & 0xfc))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x10 == (preceding_msb & 0xfc))
+                          there_is_preceding_non_skip_insn = 0;
 
-                        if (there_is_preceeding_non_skip_insn == 0)
+                        if (there_is_preceding_non_skip_insn == 0)
                           if (debug_relax)
-                            printf ("preceeding skip insn prevents deletion of"
+                            printf ("preceding skip insn prevents deletion of"
                                     " ret insn at addr 0x%x in section %s\n",
                                     (int) dot + 2, sec->name);
                       }
                     else
                       {
                         /* There is no previous instruction.  */
-                        there_is_preceeding_non_skip_insn = 0;
+                        there_is_preceding_non_skip_insn = 0;
                       }
 
-                    if (there_is_preceeding_non_skip_insn)
+                    if (there_is_preceding_non_skip_insn)
                       {
                         /* We now only have to make sure that there is no
                            local label defined at the address of the ret
--- binutils-2.20.90.20101121.orig/gas/as.c
+++ binutils-2.20.90.20101121/gas/as.c
@@ -456,7 +456,7 @@
   static const struct option std_longopts[] =
   {
     /* Note: commas are placed at the start of the line rather than
-       the end of the preceeding line so that it is simpler to
+       the end of the preceding line so that it is simpler to
        selectively add and remove lines from this list.  */
     {"alternate", no_argument, NULL, OPTION_ALTERNATE}
     /* The entry for "a" is here to prevent getopt_long_only() from
--- binutils-2.20.90.20101121.orig/gas/po/es.po
+++ binutils-2.20.90.20101121/gas/po/es.po
@@ -16085,7 +16085,7 @@
 
 #: read.c:2939
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr "se encontr? .end%c sin un %s precedente"
 
 #: read.c:2969
@@ -17653,7 +17653,7 @@
 #~ msgid "operand %s0x%x out of range"
 #~ msgstr "el operando %s0x%x est? fuera de rango"
 
-#~ msgid ".endr encountered without preceeding .rept, .irc, or .irp"
+#~ msgid ".endr encountered without preceding .rept, .irc, or .irp"
 #~ msgstr "se encontr? una directiva .endr sin una directiva .rept, .irc, ? 
.irp precedente"
 
 #~ msgid "subsegment index too high"
--- binutils-2.20.90.20101121.orig/gas/po/fr.po
+++ binutils-2.20.90.20101121/gas/po/fr.po
@@ -14430,7 +14430,7 @@
 
 #: read.c:2897
 #, fuzzy, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ".end%s n'est pas pr?c?d? de .%s"
 
 #: read.c:2927
@@ -15846,7 +15846,7 @@
 #~ msgid "can't continue"
 #~ msgstr "ne peut poursuivre"
 
-#~ msgid ".endr encountered without preceeding .rept, .irc, or .irp"
+#~ msgid ".endr encountered without preceding .rept, .irc, or .irp"
 #~ msgstr ""
 #~ "directive .end rencontr?e sans directive .rept, .irc ou .irp la pr?c?dant"
 
--- binutils-2.20.90.20101121.orig/gas/po/gas.pot
+++ binutils-2.20.90.20101121/gas/po/gas.pot
@@ -16312,7 +16312,7 @@
 
 #: read.c:2949
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2979 read.c:3009
--- binutils-2.20.90.20101121.orig/gas/po/id.po
+++ binutils-2.20.90.20101121/gas/po/id.po
@@ -16057,7 +16057,7 @@
 
 #: read.c:2939
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ".end%c ditemui tanpa diawali %s"
 
 #: read.c:2969
--- binutils-2.20.90.20101121.orig/gas/po/ru.po
+++ binutils-2.20.90.20101121/gas/po/ru.po
@@ -15638,7 +15638,7 @@
 
 #: read.c:2939
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2969
--- binutils-2.20.90.20101121.orig/gas/po/rw.po
+++ binutils-2.20.90.20101121/gas/po/rw.po
@@ -13588,7 +13588,7 @@
 
 #: read.c:2897
 #, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr ""
 
 #: read.c:2927
--- binutils-2.20.90.20101121.orig/gas/po/tr.po
+++ binutils-2.20.90.20101121/gas/po/tr.po
@@ -14321,7 +14321,7 @@
 
 #: read.c:2897
 #, fuzzy, c-format
-msgid ".end%c encountered without preceeding %s"
+msgid ".end%c encountered without preceding %s"
 msgstr "??ncesinde .%s olmayan .end%s"
 
 #: read.c:2927
@@ -15789,7 +15789,7 @@
 #~ msgid "operand %s0x%x out of range"
 #~ msgstr "%s0x%x i??leneni kapsam d??????"
 
-#~ msgid ".endr encountered without preceeding .rept, .irc, or .irp"
+#~ msgid ".endr encountered without preceding .rept, .irc, or .irp"
 #~ msgstr "??ncesinde .rept, .irc veya .irp olmaks??z??n .endr"
 
 #~ msgid "subsegment index too high"
--- binutils-2.20.90.20101121.orig/gas/read.c
+++ binutils-2.20.90.20101121/gas/read.c
@@ -2946,7 +2946,7 @@
 static void
 s_bad_end (int endr)
 {
-  as_warn (_(".end%c encountered without preceeding %s"),
+  as_warn (_(".end%c encountered without preceding %s"),
           endr ? 'r' : 'm',
           endr ? ".rept, .irp, or .irpc" : ".macro");
   demand_empty_rest_of_line ();
--- binutils-2.20.90.20101121.orig/include/coff/i860.h
+++ binutils-2.20.90.20101121/include/coff/i860.h
@@ -58,7 +58,7 @@
 #define RELSZ 10
 
 /* The relocation directory entry types.
-     PAIR   : The low half that follows relates to the preceeding HIGH[ADJ].
+     PAIR   : The low half that follows relates to the preceding HIGH[ADJ].
      HIGH   : The high half of a 32-bit constant.
      LOWn   : The low half, insn bits 15..(n-1), 2^n-byte aligned. 
      SPLITn : The low half, insn bits 20..16 and 10..(n-1), 2^n-byte aligned. 
--- binutils-2.20.90.20101121.orig/include/elf/reloc-macros.h
+++ binutils-2.20.90.20101121/include/elf/reloc-macros.h
@@ -48,7 +48,7 @@
    set to the value of the whichever *_RELOC macro preceeds it plus
    one.  Therefore if you intend to use the symbol as a sentinel for
    the highest valid macro value you should make sure that the
-   preceeding *_RELOC macro is the highest valid number.  ie a
+   preceding *_RELOC macro is the highest valid number.  ie a
    declaration like this:
 
        START_RELOC_NUMBERS (foo)
--- binutils-2.20.90.20101121.orig/opcodes/arm-dis.c
+++ binutils-2.20.90.20101121/opcodes/arm-dis.c
@@ -4678,7 +4678,7 @@
          if (!found)
            {
              /* No mapping symbol found at this address.  Look backwards
-                for a preceeding one.  */
+                for a preceding one.  */
              for (n = start - 1; n >= 0; n--)
                {
                  if (get_map_sym_type (info, n, &type))
@@ -4738,7 +4738,7 @@
          if (!found)
            {
              /* No mapping symbol found at this address.  Look backwards
-                for a preceeding one.  */
+                for a preceding one.  */
              for (n = start - 1; n >= 0; n--)
                {
                  if (get_sym_code_type (info, n, &type))
@@ -4958,5 +4958,5 @@
             regnames[i].description);
 
   fprintf (stream, "  force-thumb              Assume all insns are Thumb 
insns\n");
-  fprintf (stream, "  no-force-thumb           Examine preceeding label to 
determine an insn's type\n\n");
+  fprintf (stream, "  no-force-thumb           Examine preceding label to 
determine an insn's type\n\n");
 }
--- binutils-2.20.90.20101121.orig/bfd/vms-alpha.c
+++ binutils-2.20.90.20101121/bfd/vms-alpha.c
@@ -439,7 +439,7 @@
 {
   struct bfd_link_hash_table root;
 
-  /* Vector of shared libaries.  */
+  /* Vector of shared libraries.  */
   struct vector_type shrlibs;
 
   /* Fixup section.  */
--- binutils-2.20.90.20101121.orig/gold/dynobj.h
+++ binutils-2.20.90.20101121/gold/dynobj.h
@@ -637,7 +637,7 @@
   // Contents of --version-script, if passed, or NULL.
   const Version_script_info& version_script_;
   // Whether we need to insert a base version.  This is only used for
-  // shared libaries and is cleared when the base version is defined.
+  // shared libraries and is cleared when the base version is defined.
   bool needs_base_version_;
 };
 
--- binutils-2.20.90.20101121.orig/ld/lexsup.c
+++ binutils-2.20.90.20101121/ld/lexsup.c
@@ -449,7 +449,7 @@
     '\0', NULL, N_("Do not allow unresolved references in object files"),
     TWO_DASHES },
   { {"allow-shlib-undefined", no_argument, NULL, OPTION_ALLOW_SHLIB_UNDEFINED},
-    '\0', NULL, N_("Allow unresolved references in shared libaries"),
+    '\0', NULL, N_("Allow unresolved references in shared libraries"),
     TWO_DASHES },
   { {"no-allow-shlib-undefined", no_argument, NULL,
      OPTION_NO_ALLOW_SHLIB_UNDEFINED},
--- binutils-2.20.90.20101121.orig/ld/po/bg.po
+++ binutils-2.20.90.20101121/ld/po/bg.po
@@ -1672,7 +1672,7 @@
 msgstr "?????????????????????? ???????????????????? ???????????????? ?????? 
?????????????? ??????????????"
 
 #: lexsup.c:426
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "?????????????????? ???????????????????? ???????????????? ?????? 
?????????????????? ????????????????????"
 
 #: lexsup.c:430
--- binutils-2.20.90.20101121.orig/ld/po/es.po
+++ binutils-2.20.90.20101121/ld/po/es.po
@@ -1679,7 +1679,7 @@
 msgstr "No permite referencias sin resolver en ficheros objeto"
 
 #: lexsup.c:426
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Permite referencias sin resolver en bibliotecas compartidas"
 
 #: lexsup.c:430
--- binutils-2.20.90.20101121.orig/ld/po/fi.po
+++ binutils-2.20.90.20101121/ld/po/fi.po
@@ -1699,7 +1699,7 @@
 msgstr "??l?? salli ratkaisemattomia viitteit?? objektitiedostoissa"
 
 #: lexsup.c:424
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Salli ratkaisemattomia viitteit?? jaetuissa kirjastoissa"
 
 #: lexsup.c:428
--- binutils-2.20.90.20101121.orig/ld/po/fr.po
+++ binutils-2.20.90.20101121/ld/po/fr.po
@@ -1552,7 +1552,7 @@
 msgstr "Ne pas permettre les r??f??rences ind??finis dans les objets partag??s"
 
 #: lexsup.c:413
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Permettre les r??f??rences non r??solues dans les biblioth??ques 
partag??es"
 
 #: lexsup.c:417
--- binutils-2.20.90.20101121.orig/ld/po/ga.po
+++ binutils-2.20.90.20101121/ld/po/ga.po
@@ -1549,7 +1549,7 @@
 msgstr "N? ceadaigh tagairt? gan r?iteach i gcomhaid r?ada"
 
 #: lexsup.c:413
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Ceadaigh tagairt? gan r?iteach i gcomhleabharlanna"
 
 #: lexsup.c:417
--- binutils-2.20.90.20101121.orig/ld/po/id.po
+++ binutils-2.20.90.20101121/ld/po/id.po
@@ -1671,7 +1671,7 @@
 msgstr "Jangan perbolehkan referensi tidak terselesaikan dalam berkas objek"
 
 #: lexsup.c:424
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Ijinkan referensi tidak terselesaikan dalam perpustakaan terbagi"
 
 #: lexsup.c:428
--- binutils-2.20.90.20101121.orig/ld/po/ld.pot
+++ binutils-2.20.90.20101121/ld/po/ld.pot
@@ -1722,7 +1722,7 @@
 msgstr ""
 
 #: lexsup.c:452
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr ""
 
 #: lexsup.c:456
--- binutils-2.20.90.20101121.orig/ld/po/tr.po
+++ binutils-2.20.90.20101121/ld/po/tr.po
@@ -1545,7 +1545,7 @@
 
 #: lexsup.c:391
 #, fuzzy
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Payla????ml?? kitapl??klara ba??lanmaz"
 
 #: lexsup.c:395
--- binutils-2.20.90.20101121.orig/ld/po/vi.po
+++ binutils-2.20.90.20101121/ld/po/vi.po
@@ -1670,7 +1670,7 @@
 msgstr "?????ng cho ph??p tham chi???u ch??a th??o g??? trong t???p tin ?????i 
t?????ng"
 
 #: lexsup.c:426
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "Cho ph??p tham chi???u ch??a th??o g??? trong th?? vi???n d??ng chung"
 
 #: lexsup.c:430
--- binutils-2.20.90.20101121.orig/ld/po/zh_CN.po
+++ binutils-2.20.90.20101121/ld/po/zh_CN.po
@@ -1540,7 +1540,7 @@
 msgstr "??????????????????????????????????????????????????????"
 
 #: lexsup.c:391
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "???????????????????????????????????????????????????"
 
 #: lexsup.c:395
--- binutils-2.20.90.20101121.orig/ld/po/zh_TW.po
+++ binutils-2.20.90.20101121/ld/po/zh_TW.po
@@ -1496,7 +1496,7 @@
 msgstr "??????????????????????????????????????????????????????"
 
 #: lexsup.c:392
-msgid "Allow unresolved references in shared libaries"
+msgid "Allow unresolved references in shared libraries"
 msgstr "??????????????????????????????????????????????????????"
 
 #: lexsup.c:396
--- binutils-2.20.90.20101121.orig/binutils/readelf.c
+++ binutils-2.20.90.20101121/binutils/readelf.c
@@ -1922,7 +1922,7 @@
     case EM_MMA:               return "Fujitsu Multimedia Accelerator";
     case EM_PCP:               return "Siemens PCP";
     case EM_NCPU:              return "Sony nCPU embedded RISC processor";
-    case EM_NDR1:              return "Denso NDR1 microprocesspr";
+    case EM_NDR1:              return "Denso NDR1 microprocessor";
     case EM_STARCORE:          return "Motorola Star*Core processor";
     case EM_ME16:              return "Toyota ME16 processor";
     case EM_ST100:             return "STMicroelectronics ST100 processor";
--- binutils-2.20.90.20101121.orig/include/elf/common.h
+++ binutils-2.20.90.20101121/include/elf/common.h
@@ -159,7 +159,7 @@
 #define EM_MMA          54     /* Fujitsu Multimedia Accelerator */
 #define EM_PCP          55     /* Siemens PCP */
 #define EM_NCPU                 56     /* Sony nCPU embedded RISC processor */
-#define EM_NDR1                 57     /* Denso NDR1 microprocesspr */
+#define EM_NDR1                 57     /* Denso NDR1 microprocessor */
 #define EM_STARCORE     58     /* Motorola Star*Core processor */
 #define EM_ME16                 59     /* Toyota ME16 processor */
 #define EM_ST100        60     /* STMicroelectronics ST100 processor */

Reply via email to
--- binutils-2.20.90.20101121.orig/libiberty/pex-win32.c
+++ binutils-2.20.90.20101121/libiberty/pex-win32.c
@@ -349,14 +349,14 @@
     {
       /* We quote every last argument.  This simplifies the problem;
         we need only escape embedded double-quotes and immediately
-        preceeding backslash characters.  A sequence of backslach characters
+        preceding backslash characters.  A sequence of backslach characters
         that is not follwed by a double quote character will not be
         escaped.  */
       for (j = 0; argv[i][j]; j++)
        {
          if (argv[i][j] == '"')
            {
              /* Escape preceeding backslashes.  */
              for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
                cmdline_len++;
              /* Escape the qote character.  */
@@ -349,14 +349,14 @@
          if (argv[i][j] == '"')
            {
-             /* Escape preceeding backslashes.  */
+             /* Escape preceding backslashes.  */
              for (k = j - 1; k >= 0 && argv[i][k] == '\\'; k--)
                cmdline_len++;